You can use this package to improve your console inputs 
[Github](https://github.com/softskate/console-utils) 
The project to be continued

Simple usage:
  from console_utils import calendar_date
  selected_date = calendar_date()